@@ -28,7 +28,6 @@ use crate::{
       datareader::{DataReader, DataReaderCdr},
       datawriter::DataWriterCdr,
     },
-    Publisher, Subscriber,
   },
   discovery::{
     data_types::{
@@ -102,11 +101,13 @@ pub(crate) struct Discovery {
   self_locators: HashMap<Token, Vec<Locator>>,
 
   // DDS Subsciber and Publisher for Discovery
-  discovery_subscriber: Subscriber,
-  discovery_publisher: Publisher,
+  // ...but these are not actually used after initialization
+  //discovery_subscriber: Subscriber,
+  //discovery_publisher: Publisher,
 
   // Handling of "DCPSParticipant" topic. This is the mother of all topics
   // where participants announce their presence and built-in readers and writers.
+  #[allow(dead_code)] // Technically, the topic is not accesssed after initialization
   dcps_participant_topic: Topic,
   dcps_participant_reader: DataReader<
     SpdpDiscoveredParticipantData,
@@ -117,6 +118,7 @@ pub(crate) struct Discovery {
   participant_send_info_timer: Timer<()>, // timer to periodically announce our presence
 
   // Topic "DCPSSubscription" - announcing and detecting Readers
+  #[allow(dead_code)] // Technically, the topic is not accesssed after initialization
   dcps_subscription_topic: Topic,
   dcps_subscription_reader:
     DataReader<DiscoveredReaderData, PlCdrDeserializerAdapter<DiscoveredReaderData>>,
@@ -124,6 +126,7 @@ pub(crate) struct Discovery {
   readers_send_info_timer: Timer<()>,
 
   // Topic "DCPSPublication" - announcing and detecting Writers
+  #[allow(dead_code)] // Technically, the topic is not accesssed after initialization
   dcps_publication_topic: Topic,
   dcps_publication_reader:
     DataReader<DiscoveredWriterData, PlCdrDeserializerAdapter<DiscoveredWriterData>>,
@@ -131,6 +134,7 @@ pub(crate) struct Discovery {
   writers_send_info_timer: Timer<()>,
 
   // Topic "DCPSTopic" - annoncing and detecting topics
+  #[allow(dead_code)] // Technically, the topic is not accesssed after initialization
   dcps_topic_topic: Topic,
   dcps_topic_reader: DataReader<DiscoveredTopicData, PlCdrDeserializerAdapter<DiscoveredTopicData>>,
   dcps_topic_writer: DataWriterCdr<DiscoveredTopicData>,
@@ -138,6 +142,7 @@ pub(crate) struct Discovery {
   topic_cleanup_timer: Timer<()>,
 
   // DCPSParticipantMessage - used by participants to communicate liveness
+  #[allow(dead_code)] // Technically, the topic is not accesssed after initialization
   participant_message_topic: Topic,
   dcps_participant_message_reader: DataReaderCdr<ParticipantMessageData>,
   dcps_participant_message_writer: DataWriterCdr<ParticipantMessageData>,
@@ -524,9 +529,8 @@ impl Discovery {
 
       liveliness_state: LivelinessState::new(),
 
-      discovery_subscriber,
-      discovery_publisher,
-
+      // discovery_subscriber,
+      // discovery_publisher,
       dcps_participant_topic,
       dcps_participant_reader,
       dcps_participant_writer,
@@ -802,7 +806,7 @@ impl Discovery {
     // This will read the participant from Discovery DB and construct
     // ReaderProxy and WriterProxy objects for built-in Readers and Writers
     self.send_discovery_notification(DiscoveryNotificationType::ParticipantUpdated {
-      guid_prefix: dp.guid().guid_prefix,
+      guid_prefix: dp.guid().prefix,
     });
 
     // insert a (fake) reader proxy as multicast address, so discovery notifications
@@ -838,10 +842,7 @@ impl Discovery {
       content_filter: None,
     };
 
-    let writer_guid = GUID::new(
-      dp.guid().guid_prefix,
-      EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER,
-    );
+    let writer_guid = GUID::new(dp.guid().prefix, EntityId::SPDP_BUILTIN_PARTICIPANT_WRITER);
 
     let writer_proxy = WriterProxy::new(
       writer_guid,
@@ -901,7 +902,7 @@ impl Discovery {
             let was_new = self
               .discovery_db_write()
               .update_participant(&participant_data);
-            let guid_prefix = participant_data.participant_guid.guid_prefix;
+            let guid_prefix = participant_data.participant_guid.prefix;
             self.send_discovery_notification(DiscoveryNotificationType::ParticipantUpdated {
               guid_prefix,
             });
@@ -917,12 +918,12 @@ impl Discovery {
             }
           }
           // Err means that DomainParticipant was disposed
-          Err(guid) => {
+          Err(data_key) => {
             self
               .discovery_db_write()
-              .remove_participant(guid.0.guid_prefix);
+              .remove_participant(data_key.0.prefix);
             self.send_discovery_notification(DiscoveryNotificationType::ParticipantLost {
-              guid_prefix: guid.0.guid_prefix,
+              guid_prefix: data_key.0.prefix,
             });
           }
         },
@@ -961,7 +962,7 @@ impl Discovery {
           let mut db = self.discovery_db_write();
           trace!("handle_subscription_reader discovered {:?}", &d);
           if read_history
-            .map(|e| e == d.reader_proxy.remote_reader_guid.guid_prefix)
+            .map(|e| e == d.reader_proxy.remote_reader_guid.prefix)
             .unwrap_or(true)
           {
             if let Some((drd, rtps_reader_proxy)) = db.update_subscription(&d) {
@@ -1163,8 +1164,7 @@ impl Discovery {
         if current_duration > mm {
           let pp = ParticipantMessageData {
             guid: self.domain_participant.guid_prefix(),
-            kind:
-              ParticipantMessageDataKind::PARTICIPANT_MESSAGE_DATA_KIND_AUTOMATIC_LIVELINESS_UPDATE,
+            kind: ParticipantMessageDataKind::AUTOMATIC_LIVELINESS_UPDATE,
             data: Vec::new(),
           };
           match self.dcps_participant_message_writer.write(pp, None) {
@@ -1195,8 +1195,7 @@ impl Discovery {
         if current_duration > dur {
           let pp = ParticipantMessageData {
             guid: self.domain_participant.guid_prefix(),
-            kind:
-              ParticipantMessageDataKind::PARTICIPANT_MESSAGE_DATA_KIND_MANUAL_LIVELINESS_UPDATE,
+            kind: ParticipantMessageDataKind::MANUAL_LIVELINESS_UPDATE,
             data: Vec::new(),
           };
           match self.dcps_participant_message_writer.write(pp, None) {
