@@ -100,7 +100,7 @@ impl DiscoveryDB {
     // }
 
     let mut new_participant = false;
-    if self.participant_proxies.get(&guid.guid_prefix).is_none() {
+    if self.participant_proxies.get(&guid.prefix).is_none() {
       info!("New remote participant: {:?}", &data);
       new_participant = true;
       if guid == self.my_guid {
@@ -112,12 +112,10 @@ impl DiscoveryDB {
       }
     }
     // actual work here:
-    self
-      .participant_proxies
-      .insert(guid.guid_prefix, data.clone());
+    self.participant_proxies.insert(guid.prefix, data.clone());
     self
       .participant_last_life_signs
-      .insert(guid.guid_prefix, Instant::now());
+      .insert(guid.prefix, Instant::now());
 
     new_participant
   }
@@ -153,10 +151,6 @@ impl DiscoveryDB {
     self.participant_proxies.get(&guid_prefix)
   }
 
-  pub fn find_remote_reader(&self, guid: GUID) -> Option<&DiscoveredReaderData> {
-    self.external_topic_readers.get(&guid)
-  }
-
   fn remove_topic_reader_with_prefix(&mut self, guid_prefix: GuidPrefix) {
     // TODO: Implement this using .drain_filter() in BTreeMap once it lands in
     // stable.
@@ -209,8 +203,8 @@ impl DiscoveryDB {
         Some(&last_life) => {
           // keep, if duration not exeeded
           let elapsed = Duration::from_std(inow.duration_since(last_life));
-          if elapsed <= lease_duration {
-            // this is a keeper
+          if elapsed <= lease_duration + PARTICIPANT_LEASE_DURATION_TOLREANCE {
+            // No timeout yet, we keep this, so do nothng.
           } else {
             info!("participant cleanup - deleting participant proxy {:?}. lease_duration = {:?} elapsed = {:?}",
                   guid, lease_duration, elapsed);
@@ -280,10 +274,6 @@ impl DiscoveryDB {
     }
   }
 
-  pub fn participants(&self) -> impl Iterator<Item = &SpdpDiscoveredParticipantData> {
-    self.participant_proxies.values()
-  }
-
   pub fn update_local_topic_writer(&mut self, writer: DiscoveredWriterData) {
     self
       .local_topic_writers
@@ -296,13 +286,17 @@ impl DiscoveryDB {
     self.writers_updated = true;
   }
 
-  pub fn external_reader_proxies<'a>(&'a self) -> impl Iterator<Item = &DiscoveredReaderData> + 'a {
-    self.external_topic_readers.values()
-  }
+  // pub fn participants(&self) -> impl Iterator<Item =
+  // &SpdpDiscoveredParticipantData> {   self.participant_proxies.values()
+  // }
 
-  pub fn external_writer_proxies<'a>(&'a self) -> impl Iterator<Item = &DiscoveredWriterData> + 'a {
-    self.external_topic_writers.values()
-  }
+  // pub fn external_reader_proxies<'a>(&'a self) -> impl Iterator<Item =
+  // &DiscoveredReaderData> + 'a {   self.external_topic_readers.values()
+  // }
+
+  // pub fn external_writer_proxies<'a>(&'a self) -> impl Iterator<Item =
+  // &DiscoveredWriterData> + 'a {   self.external_topic_writers.values()
+  // }
 
   // TODO: This is silly. Returns one of the paramters cloned, or None
   // TODO: Why are we here checking if discovery db already has this? What about
@@ -321,7 +315,7 @@ impl DiscoveryDB {
         self.external_topic_readers.insert(guid, data.clone());
         // fill in the default locators, in case DRD did not provide any
         let default_locator_lists = self
-          .find_participant_proxy(guid.guid_prefix)
+          .find_participant_proxy(guid.prefix)
           .map(|pp| {
             debug!("Added default locators to Reader {:?}", guid);
             (
@@ -330,12 +324,12 @@ impl DiscoveryDB {
             )
           })
           .unwrap_or_else(|| {
-            if guid.guid_prefix != GuidPrefix::UNKNOWN {
+            if guid.prefix != GuidPrefix::UNKNOWN {
               // This is normal, since we might not know about the participant yet.
               debug!(
                 "No remote participant known for {:?}\nSearched with {:?} in {:?}",
                 data,
-                guid.guid_prefix,
+                guid.prefix,
                 self.participant_proxies.keys()
               );
             }
@@ -529,10 +523,6 @@ impl DiscoveryDB {
     self.topics.get(topic_name)
   }
 
-  pub fn new_topic_token() -> mio::Token {
-    mio::Token(0)
-  }
-
   // // TODO: return iterator somehow?
   #[cfg(test)] // used only for testing
   pub fn get_local_topic_readers<'a, T: TopicDescription>(
