@@ -745,7 +745,13 @@ impl BuiltinDataDeserializer {
         buffer.clear();
         return self;
       }
-      _ => (),
+      ParameterId::PID_PAD => {
+        buffer.drain(..4 + parameter_length);
+        return self;
+      }
+      _ => (), /* TODO: Add some logging. But not much, since there may
+                * be some legitimate cases where we encounter paraneters that we do not
+                * know. */
     }
 
     buffer.drain(..4 + parameter_length);
