@@ -17,12 +17,12 @@ use crate::{
 };
 
 /// This type adapts CdrDeserializer (which implements serde::Deserializer) to
-/// work as a [`DeserializerAdapter`]. CdrDeserializer cannot directly implement
+/// work as a [`with_key::DeserializerAdapter`] and
+/// [`no_key::DeserializerAdapter`].
+///
+/// CdrDeserializer cannot directly implement
 /// the trait itself, because CdrDeserializer has the type parameter BO open,
 /// and the adapter needs to be bi-endian.
-///
-/// [`DeserializerAdapter`]:
-/// ../dds/traits/serde_adapters/trait.DeserializerAdapter.html
 pub struct CDRDeserializerAdapter<D> {
   phantom: PhantomData<D>,
   // no-one home
@@ -75,7 +75,8 @@ where
   }
 }
 
-/// CDR deserializer.
+/// a CDR deserializer implementation.
+///
 /// Input is from &[u8], since we expect to have the data in contiguous memory
 /// buffers.
 pub struct CdrDeserializer<'de, BO> {
@@ -123,15 +124,6 @@ where
     Ok(())
   }
 
-  // Look at the first byte in the input without consuming it.
-  fn peek_byte(&mut self) -> Result<u8> {
-    self.input.first().ok_or(Error::Eof).map(|b| *b)
-  }
-
-  fn check_if_bytes_left(&mut self) -> bool {
-    !self.input.is_empty()
-  }
-
   fn calculate_padding_count_from_written_bytes_and_remove(
     &mut self,
     type_octet_aligment: usize,
